import setuptools

setuptools.setup(
	name="deepak-packages",
	version="1.0.0",
	packages=["trainingpack"],
	package_dir={"trainingpack":"./trainingpack"},
	author="Deepak",
	author_email="abc@xyz.com",
	maintainer="Deepak",
	maintainer_email="abc@xyz.com",
	description="Sample Package",
	license="MIT")